import matplotlib
import pylab
import numpy as N
from matplotlib.ticker import LogLocator,MultipleLocator, FormatStrFormatter
matplotlib.rcParams['legend.fontsize']=6

majorLocator1   = LogLocator(10,[1,2,5])
majorFormatter1 = FormatStrFormatter('$%g$')

"""
****************** plot Pk
"""

labels = ["0.5-0.6","0.6-0.8","0.8-1.0"]
k,pk,sigpk = N.loadtxt("cfhtls_pk_est.txt",unpack=True,comments='#')
n = len(k)/3
print n

for i in range(3):
    a = i*n
    b = a+n

    pylab.errorbar(k[a:b],pk[a:b],yerr = sigpk[a:b],label=labels[i])

pylab.legend()
ax = pylab.gca()
ax.set_xscale('log')
ax.set_yscale('log')
ax.xaxis.set_major_locator(majorLocator1)
ax.xaxis.set_major_formatter(majorFormatter1)

pylab.xlim(.03,0.7)
pylab.ylim(300,35000)

pylab.xlabel('$k~({\\rm h}~{\\rm Mpc}^{-1})$')
pylab.ylabel("$P_k~({\\rm h}^{-3} {~\\rm Mpc}^{3})$")

pylab.savefig("plots/pk_est.png",dpi=300)


"""
****************** plot the windows
"""
pylab.figure(figsize=(5,3))

windows = N.loadtxt("cfhtls_pk_windows.txt",comments='#')
scale = windows[0]
win = windows[1:]

for w in win:
    pylab.plot(scale,w)

ax = pylab.gca()
ax.set_xscale('log')
ax.xaxis.set_major_locator(majorLocator1)
ax.xaxis.set_major_formatter(majorFormatter1)
pylab.xlabel('$k~({\\rm h}~{\\rm Mpc}^{-1})$')
pylab.ylabel("window function")
pylab.savefig("plots/pk_windows.png",dpi=300)


"""
****************** plot cov mat
"""
pylab.figure(figsize=(5,4))
cmat = N.loadtxt("cfhtls_pk_covariance.txt",comments='#')
scale = cmat[0]
cmat = cmat[1:]


from matplotlib.ticker import LogFormatterMathtext
formatter = LogFormatterMathtext(10)
cmap = pylab.get_cmap('PuBu')

c = N.abs(cmat)
norm = matplotlib.colors.LogNorm(vmin=c.min(), vmax=c.max(), clip=False)
pylab.imshow(c, cmap=cmap, norm=norm, origin='lower')
cb = pylab.colorbar(cmap=cmap,norm=norm, format=formatter, orientation='vertical'),
pylab.savefig("plots/cmat.png",dpi=300)


"""
****************** plot redshift distributions
"""
pylab.figure()

paths = ('zdist/zdisthist_All_5-6_i225.txt',
         'zdist/zdisthist_All_6-8_i225.txt',
         'zdist/zdisthist_All_8-10_i225.txt')

for p in paths:
    z,n = N.loadtxt(p,unpack=True)
    pylab.plot(z,n)

pylab.xlabel("Redshift")
pylab.ylabel("N")
pylab.xlim(0,1.5)
pylab.savefig("plots/zdist.png",dpi=300)


pylab.show()
