import matplotlib
import pylab
import numpy as N
from matplotlib.ticker import LogLocator,MultipleLocator, FormatStrFormatter
matplotlib.rcParams['legend.fontsize']=6

"""
****************** plot Cl
"""

labels = ["0.5-0.6","0.6-0.8","0.8-1.0"]
k,pk,sigpk = N.loadtxt("cfhtls_cl_est.txt",unpack=True,comments='#')
n = len(k)/3
print n
scale = 1e4

for i in range(3):
    a = i*n
    b = a+n

    pylab.errorbar(k[a:b],1e4*pk[a:b],yerr = 1e4*sigpk[a:b],label=labels[i])

pylab.legend()
ax = pylab.gca()


pylab.xlabel('$l$')
pylab.ylabel("$l C_l \\times 10^4$")

pylab.savefig("plots/cl_est.png",dpi=300)


"""
****************** plot the windows
"""
pylab.figure(figsize=(5,3))

windows = N.loadtxt("cfhtls_cl_windows.txt",comments='#')
scale = windows[0]
win = windows[1:]

for w in win:
    pylab.plot(scale,w)

ax = pylab.gca()

pylab.xlabel('$l$')
pylab.ylabel("window function")
pylab.savefig("plots/cl_windows.png",dpi=300)


"""
****************** plot cov mat
"""
pylab.figure(figsize=(5,4))
cmat = N.loadtxt("cfhtls_cl_covariance.txt",comments='#')
scale = cmat[0]
cmat = cmat[1:]


from matplotlib.ticker import LogFormatterMathtext
formatter = LogFormatterMathtext(10)
cmap = pylab.get_cmap('PuBu')

c = N.abs(cmat)
norm = matplotlib.colors.LogNorm(vmin=c.min(), vmax=c.max(), clip=False)
pylab.imshow(c, cmap=cmap, norm=norm, origin='lower')
cb = pylab.colorbar(cmap=cmap,norm=norm, format=formatter, orientation='vertical'),
pylab.savefig("plots/cmat_cl.png",dpi=300)



pylab.show()
